DraggableAnimationDisplay class abstract

Implementers

Constructors

DraggableAnimationDisplay({required double spacingX, required double percentag, bool compareItemPosition(DraggableAnimationItem dragItem, DraggableAnimationItem item)?})
const

Properties

compareItemPosition bool Function(DraggableAnimationItem dragItem, DraggableAnimationItem item)?
final
hashCode int
The hash code for this object.
no setterinherited
percentag double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacingX double
final

Methods

compareItemPositionWithPercentag(DraggableAnimationItem item, DraggableAnimationItem compareItem, {ItemOffset? itemOffset}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLayoutPosition(List<DraggableAnimationItem> targetItemList, Size layoutSize) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited