DraggableAnimationGridDisplay class
- Inheritance
-
- Object
- DraggableAnimationDisplay
- DraggableAnimationGridDisplay
Constructors
- DraggableAnimationGridDisplay({required double columnCount, required double rowHeight, required double spacingY, required double spacingX, double percentag = .5, bool compareItemPosition(DraggableAnimationItem dragItem, DraggableAnimationItem item)?})
Properties
- columnCount → double
-
final
- compareItemPosition → bool Function(DraggableAnimationItem dragItem, DraggableAnimationItem item)?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- percentag → double
-
finalinherited
- rowHeight → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacingX → double
-
finalinherited
- spacingY → double
-
final
Methods
-
compareItemPositionWithPercentag(
DraggableAnimationItem item, DraggableAnimationItem compareItem, {ItemOffset? itemOffset}) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLayoutPosition(
List< DraggableAnimationItem> targetItemList, Size layoutSize) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited