DraggableAnimationRowDisplay class

Inheritance

Constructors

DraggableAnimationRowDisplay({required double colWidth, required double spacingX, double percentag = .5, bool compareItemPosition(DraggableAnimationItem dragItem, DraggableAnimationItem item)?})

Properties

colWidth double
getter/setter pair
compareItemPosition bool Function(DraggableAnimationItem dragItem, DraggableAnimationItem item)?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
percentag double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacingX double
finalinherited

Methods

compareItemPositionWithPercentag(DraggableAnimationItem item, DraggableAnimationItem compareItem, {ItemOffset? itemOffset}) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLayoutPosition(List<DraggableAnimationItem> targetItemList, Size layoutSize) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited